if IsAddOnLoaded("PetTracker") then
print(OMEGAMAP_PETTRACKER_LOADED_MESSAGE)

if not PetTrackerOmegaMapOverlay then
	local overlay = CreateFrame("Frame", "PetTrackerOmegaMapOverlay", OmegaMapDetailFrame)
	overlay:SetAllPoints(true)
end

local ADDON, Addon = "PetTracker", PetTracker
local Journal = Addon.Journal
local MapFrame, BlipParent = OmegaMapDetailFrame, OmegaMapDetailFrame

local Map = Addon:NewModule('OmegaMap', OMPetTrackerMapFilter)
local Tooltip = Addon.MapTip(OmegaMapFrame)

local L = Addon.Locals
local Suggestions = {
	L.CommonSearches,
	L.NotMaximized,
	ADDON_MISSING
}


--[[ Events ]]--

function Map:Startup()
	self:RegisterEvent('ZONE_CHANGED_NEW_AREA')
	self:SetScript('OnTextChanged', self.FilterChanged)
	self:SetScript('OnEvent', SetMapToCurrentZone)
	self:SetScript('OnUpdate', self.UpdateTip)
	self:SetScript('OnShow', self.UpdateBlips)
	self:SetScript('OnHide', self.HideTip)

	self.DefaultText = L.FilterPets
	self:SetText(L.FilterPets)
	self:PositionFilter()
	self.blips = {}

	for i, text in ipairs(Suggestions) do
		local button = CreateFrame('Button', '$parentButton'..i, self.Suggestions, 'OMPetTrackerSuggestionButton')
		button:SetPoint('TOPLEFT', 18, -16*i + 7)
		button:SetText(text)

		if i == 1 then
			button:SetDisabledFontObject(GameFontNormalSmallLeft)
			button:Disable()
		end
	end
	--WorldMapTrackQuest:HookScript('OnShow', function() self:PositionFilter() end)
	--WorldMapTrackQuest:HookScript('OnHide', function() self:PositionFilter() end)
	OmegaMapFrame:HookScript('OnShow', function() self:UpdateBlips() end)

	hooksecurefunc('OmegaMapShowDropDown_Initialize', function()
		UIDropDownMenu_AddButton {
			text = 'Show Battle Pets',
			func = function() self:ToggleActive() end,
			checked = self:IsActive(),
			keepShownOnClick = true,
			isNotRadio = true
		}
	end)
end

function Map:TrackingChanged()
	if self:IsVisible() then 
		self:UpdateBlips()
	end
end


--[[ Blips ]]--

function Map:UpdateBlips()
	self:ResetBlips()

	if (not PetTracker_HideSpots) then
	self:SetShown(not PetTracker_HideSpots)
	end
	
	if self:IsActive() then
		self:ShowBlips()
	end
end

function Map:ShowBlips()
	local floor = GetCurrentMapDungeonLevel() - (DungeonUsesTerrainMap() and 1 or 0)
	local species = Journal:GetCurrentSpecies()
	local width, height = MapFrame:GetSize()
	
	for specie, floors in pairs(species) do
		local spots = floors[floor]
			
		if spots and Journal:Matches(specie, PetTracker_MapFilter) then
			local icon = Journal:GetTypeIcon(specie)

			for x, y in gmatch(spots, '(%w+):(%w+)') do
				local x, y = self:ParseCoords(x, y)
				local blip = Addon.SpecieBlip(BlipParent)
				blip:SetPoint('CENTER', MapFrame, 'TOPLEFT', x * width, -y * height)
				blip.icon:SetTexture(icon)
				blip:SetSpecie(specie)
				blip.x, blip.y = x, y
				blip:Show()

				tinsert(self.blips, blip)
			end
		end
	end
end

function Map:ParseCoords(x, y)
	return tonumber(x, 16) / 1000, tonumber(y, 16) / 1000
end

function Map:ResetBlips()
	for _, blip in ipairs(self.blips) do
		blip:Release()
	end

	wipe(self.blips)
end


--[[ Tooltip ]]--

function Map:UpdateTip()
	Tooltip:Anchor(BlipParent, 'ANCHOR_CURSOR')

	for i, blip in ipairs(self.blips) do
		if blip:IsMouseOver() then
			local title, text = blip:GetTooltip()
			
			Tooltip:AddHeader(title)
			Tooltip:AddLine(text, 1,1,1, true)
		end
	end

	Tooltip:Display()
end

function Map:HideTip()
	Tooltip:Hide()
end


--[[ Filter ]]--

function Map:FilterChanged()
	local text = self:GetText()
	if text == self.DefaultText then
		text = ''
	end

	PetTracker_MapFilter = text
	self:TrackingChanged()
end

function Map:PositionFilter()
		self:SetPoint('LEFT', PetTrackerOmegaMapOverlay, 'TOPLEFT', 3, -15)
end


--[[ Active ]]--

function Map:ToggleActive()
	self:SetActive(not self:IsActive())
	self:UpdateBlips()
end

function Map:SetActive(active)
	PetTracker_HideSpots = not active
	self:SetShown(active)
end

function Map:IsActive()
	return not PetTracker_HideSpots
end

end